..
    This file is part of COUNTER-Robots.
    Copyright (C) 2018-2025 CERN.
    Copyright (C) 2025 Graz University of Technology.

    COUNTER-Robots is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 2025.11 (released on 2025-11-04)

- chore(setup): update dependencies
- fix: pkg_resources DeprecationWarning

Version 2025.2 (released on 2025-02-13)

- User agents lists update.

Version 2018.6 (released on 2018-06-15)

- Initial public release.
